==> mutual_credit-5.0.9.tar.gz: mutual_credit/src/Plugin/Block/WalletContextBlockBase.php <==
<?php

namespace Drupal\mcapi\Plugin\Block;

use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Currency;
use Drupal\mcapi\Entity\Wallet;
use Drupal\user\Entity\User;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Base block class for blocks determine a wallet from the context.
 */
abstract class WalletContextBlockBase extends BlockBase implements ContainerFactoryPluginInterface {

  const HOLDER_CURRENT_USER = 1;
  const HOLDER_VISITED_ENTITY = 0;

  /**
   * @var Drupal\Core\Session\AccountProxy
   */
  protected $currentUser;

  /**
   * @var Drupal\Core\Session\AccountProxy
   */
  protected $entityTypeManager;

  /**
   * @var array
   */
  protected $wids = [];

  /**
   * @var Wallet[]
   */
  protected $wallets = [];

  /**
   * @var ContentEntity
   */
  protected $holder;

  /**
   * Constructor
   *
   * @param array $configuration
   * @param type $plugin_id
   * @param array $plugin_definition
   * @param EntityTypeManagerInterface $entity_type_manager
   * @param AccountInterface $currentUser
   * @param Request $request
   */
  public function __construct($configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, AccountInterface $currentUser, Request $request) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $currentUser;
    $this->entityTypeManager = $entity_type_manager;
    if ($this->configuration['holder_source'] == SELF::HOLDER_CURRENT_USER) {
      $this->holder = User::load(\Drupal::currentUser()->id());
    }
    elseif ($request->attributes and $request->attributes->has('_entity')) {
      $entity = $request->attributes->get('_entity');
      if ($entity instanceOf ContentEntityInterface) {
        $this->holder = $entity;
      }
    }
    if ($this->holder) {
      $this->wids = $this->entityTypeManager->getStorage('mcapi_wallet')->getQuery()
        ->accessCheck(TRUE)
        ->condition('holder.target_type', $this->holder->getEntityTypeId())
        ->condition('holder.target_id', $this->holder->id())
        ->execute();
    }
  }

  /**
   * Injection.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'curr_ids' => [],
      'holder_source' => SELF::HOLDER_VISITED_ENTITY,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockAccess(AccountInterface $account) : AccessResult {
    if (empty($this->holder)) {
      $result = AccessResult::forbidden('No wallet holder on this route');
    }
    elseif (empty($this->wids)) {
      // Not sure how to cache this.
      $result = AccessResult::forbidden('Wallet holder has no wallets: '.$this->holder->getEntityTypeId() .' '. $this->holder->id());
    }
    else {
      $result = AccessResult::allowed()->cachePerUser();
    }
    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    parent::blockForm($form, $form_state);
    if (\Drupal::entityQuery('mcapi_currency')->count()->execute() > 1) {
      $form['curr_ids'] = [
        '#title' => t('Currencies'),
        '#description' => t("Select none to select all. Also see the setting 'Show unused currencies.' on admin/accounting/misc"),
        '#title_display' => 'before',
        '#type' => 'mcapi_currency_select',
        '#default_value' => $this->configuration['curr_ids'],
        '#options' => Mcapi::entityOptionsList(Currency::loadMultiple()),
        '#multiple' => TRUE,
      ];
    }
    $form['holder_source'] = [
      '#title' => t('Entity source'),
      '#type' => 'radios',
      '#options' => array(
        static::HOLDER_VISITED_ENTITY => t('Wallets of entity on canonical page'),
        static::HOLDER_CURRENT_USER => t('Wallets of logged in user'),
      ),
      '#default_value' => $this->configuration['holder_source'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    foreach ($form_state->getValues() as $key => $val) {
      $this->configuration[$key] = $val;
    }
    $this->configuration['curr_ids'] = array_filter($this->configuration['curr_ids']);
  }

  protected function getWallets() {
    if (empty($this->wallets)) {
      $this->wallets = Wallet::loadMultiple($this->wids);
    }
    return $this->wallets;
  }

  public function build() {
    if ($this->configuration['holder_source'] == SELF::HOLDER_CURRENT_USER) {
      $context = 'user';
    }
    else {
      $context = 'url';
    }

    foreach ($this->wids as $wid) {
      $tags[] = 'mcapi_wallet:'.$wid;
    }
    return [
      '#cache' => [
        'contexts' => [$context],
        'tags' => $tags
      ]
    ];
  }

}

==> mutual_credit-5.0.12.tar.gz: mutual_credit/src/Plugin/Block/WalletContextBlockBase.php <==
<?php

namespace Drupal\mcapi\Plugin\Block;

use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Currency;
use Drupal\mcapi\Entity\Wallet;
use Drupal\user\Entity\User;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Base block class for blocks determine a wallet from the context.
 */
abstract class WalletContextBlockBase extends BlockBase implements ContainerFactoryPluginInterface {

  const HOLDER_CURRENT_USER = 1;
  const HOLDER_VISITED_ENTITY = 0;

  /**
   * @var Drupal\Core\Session\AccountProxy
   */
  protected $currentUser;

  /**
   * @var Drupal\Core\Session\AccountProxy
   */
  protected $entityTypeManager;

  /**
   * @var array
   */
  protected $wids = [];

  /**
   * @var Wallet[]
   */
  protected $wallets = [];

  /**
   * @var ContentEntity
   */
  protected $holder;

  /**
   * Constructor
   *
   * @param array $configuration
   * @param type $plugin_id
   * @param array $plugin_definition
   * @param EntityTypeManagerInterface $entity_type_manager
   * @param AccountInterface $currentUser
   * @param Request $request
   */
  public function __construct($configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, AccountInterface $currentUser, Request $request) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $currentUser;
    $this->entityTypeManager = $entity_type_manager;
    if ($this->configuration['holder_source'] == SELF::HOLDER_CURRENT_USER) {
      $this->holder = User::load(\Drupal::currentUser()->id());
    }
    elseif ($request->attributes and $request->attributes->has('_entity')) {
      $entity = $request->attributes->get('_entity');
      if ($entity instanceOf ContentEntityInterface) {
        $this->holder = $entity;
      }
    }
    if ($this->holder) {
      $this->wids = $this->entityTypeManager->getStorage('mcapi_wallet')->getQuery()
        ->accessCheck(TRUE)
        ->condition('holder.target_type', $this->holder->getEntityTypeId())
        ->condition('holder.target_id', $this->holder->id())
        ->execute();
    }
  }

  /**
   * Injection.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'curr_ids' => [],
      'holder_source' => SELF::HOLDER_VISITED_ENTITY,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockAccess(AccountInterface $account) : AccessResult {
    if (empty($this->holder)) {
      $result = AccessResult::forbidden('No wallet holder on this route');
    }
    elseif (empty($this->wids)) {
      // Not sure how to cache this.
      $result = AccessResult::forbidden('Wallet holder has no wallets: '.$this->holder->getEntityTypeId() .' '. $this->holder->id());
    }
    else {
      $result = AccessResult::allowed()->cachePerUser();
    }
    return $result;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    parent::blockForm($form, $form_state);
    if (\Drupal::entityQuery('mcapi_currency')->count()->execute() > 1) {
      $form['curr_ids'] = [
        '#title' => t('Currencies'),
        '#description' => t("Select none to select all. Also see the setting 'Show unused currencies.' on admin/accounting/misc"),
        '#title_display' => 'before',
        '#type' => 'mcapi_currency_select',
        '#default_value' => $this->configuration['curr_ids'],
        '#options' => Mcapi::entityOptions('mcapi_currency'),
        '#multiple' => TRUE,
      ];
    }
    $form['holder_source'] = [
      '#title' => t('Entity source'),
      '#type' => 'radios',
      '#options' => array(
        static::HOLDER_VISITED_ENTITY => t('Wallets of entity on canonical page'),
        static::HOLDER_CURRENT_USER => t('Wallets of logged in user'),
      ),
      '#default_value' => $this->configuration['holder_source'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    foreach ($form_state->getValues() as $key => $val) {
      $this->configuration[$key] = $val;
    }
    $this->configuration['curr_ids'] = array_filter($this->configuration['curr_ids']);
  }

  protected function getWallets() {
    if (empty($this->wallets)) {
      $this->wallets = Wallet::loadMultiple($this->wids);
    }
    return $this->wallets;
  }

  public function build() {
    if ($this->configuration['holder_source'] == SELF::HOLDER_CURRENT_USER) {
      $context = 'user';
    }
    else {
      $context = 'url';
    }

    foreach ($this->wids as $wid) {
      $tags[] = 'mcapi_wallet:'.$wid;
    }
    return [
      '#cache' => [
        'contexts' => [$context],
        'tags' => $tags
      ]
    ];
  }

}
